import * as cdk from 'aws-cdk-lib';
import * as constructs from 'constructs';
/**
 * FSx for ONTAP offers SnapMirror for efficient data replication between file systems, aiding in data protection, disaster recovery, and long-term retention. To use SnapMirror, set up cluster peering and SVM peering between the source and target FSx for ONTAP file systems. Once activated, you need a preview key to consume this resource. Please reach out to Ng-fsx-cloudformation@netapp.com to get the key. To use this resource, you must first create the Link module.
 *
 * @schema CfnSnapMirrorProps
 */
export interface CfnSnapMirrorProps {
    /**
     * The password source for the FSx admin user.
     *
     * @schema CfnSnapMirrorProps#FsxAdminPasswordSource
     */
    readonly fsxAdminPasswordSource: PasswordSource;
    /**
     * The file system ID of the Amazon FSx for NetApp ONTAP file system in which the resource is created.
     *
     * @schema CfnSnapMirrorProps#FileSystemId
     */
    readonly fileSystemId: string;
    /**
     * The ARN of the AWS Lambda function that will be invoked to manage the resource.
     *
     * @schema CfnSnapMirrorProps#LinkArn
     */
    readonly linkArn: string;
    /**
     * The destination information for the Cluster Peer relationship.
     *
     * @schema CfnSnapMirrorProps#FsxnDestinationInfo
     */
    readonly fsxnDestinationInfo: FsxnDestination;
    /**
     * Source endpoint of a SnapMirror relationship.
     *
     * @schema CfnSnapMirrorProps#SnapMirrorSourceEndpoint
     */
    readonly snapMirrorSourceEndpoint: Endpoint;
    /**
     * Destination endpoint of a SnapMirror relationship.
     *
     * @schema CfnSnapMirrorProps#SnapMirrorEndpoint
     */
    readonly snapMirrorEndpoint: Endpoint;
    /**
     * Use this object to provision the destination endpoint when establishing a SnapMirror relationship for a volume. For FlexGroup SnapMirror relationships, the source and destination FlexGroups must be spread over the same number of aggregates with the same number of constituents per aggregate.
     *
     * @schema CfnSnapMirrorProps#SnapMirrorDestinationCreation
     */
    readonly snapMirrorDestinationCreation?: SnapMirrorDestinationCreation;
    /**
     * The SnapMirror policy to be used for the SnapMirror relationship.
     *
     * @schema CfnSnapMirrorProps#Policy
     */
    readonly policy: string;
    /**
     * Throttle, in KBs per second. This 'throttle' overrides the 'throttle' set on the SnapMirror relationship's policy. If neither of these are set, the throttle defaults to 0, which is interpreted as unlimited.
     *
     * @schema CfnSnapMirrorProps#Throttle
     */
    readonly throttle?: number;
    /**
     * Schedule used to update asynchronous relationships. This 'transfer_schedule' overrides the 'transfer_schedule' set on the SnapMirror relationship's policy. Remove the property to revert. Only cron schedules are supported for SnapMirror.
     *
     * @schema CfnSnapMirrorProps#TransferSchedule
     */
    readonly transferSchedule?: string;
    /**
     * Setting state of the relationship. Can be set during modify only.
     *
     * @schema CfnSnapMirrorProps#StateAction
     */
    readonly stateAction?: CfnSnapMirrorPropsStateAction;
    /**
     * Reverse the direction of relationship by making the source endpoint as the new destination endpoint and making the destination endpoint as the new source endpoint. Can be set during modify only.
     *
     * @schema CfnSnapMirrorProps#Reverse
     */
    readonly reverse?: boolean;
    /**
     * The health status of the SnapMirror relationship.
     *
     * @schema CfnSnapMirrorProps#HealthyStatus
     */
    readonly healthyStatus?: HealthyStatus;
}
/**
 * Converts an object of type 'CfnSnapMirrorProps' to JSON representation.
 */
export declare function toJson_CfnSnapMirrorProps(obj: CfnSnapMirrorProps | undefined): Record<string, any> | undefined;
/**
 * @schema PasswordSource
 */
export interface PasswordSource {
    /**
     * A reference to the source of the password, typically an AWS Secrets Manager secret.
     *
     * @schema PasswordSource#Secret
     */
    readonly secret: SecretSource;
}
/**
 * Converts an object of type 'PasswordSource' to JSON representation.
 */
export declare function toJson_PasswordSource(obj: PasswordSource | undefined): Record<string, any> | undefined;
/**
 * @schema FsxnDestination
 */
export interface FsxnDestination {
    /**
     * The password source for the FSx admin user.
     *
     * @schema FsxnDestination#FsxAdminPasswordSource
     */
    readonly fsxAdminPasswordSource: PasswordSource;
    /**
     * The file system ID of the Amazon FSx for NetApp ONTAP file system in which the resource is created.
     *
     * @schema FsxnDestination#FileSystemId
     */
    readonly fileSystemId: string;
    /**
     * The ARN of the AWS Lambda function that will be invoked to manage the resource.
     *
     * @schema FsxnDestination#LinkArn
     */
    readonly linkArn: string;
}
/**
 * Converts an object of type 'FsxnDestination' to JSON representation.
 */
export declare function toJson_FsxnDestination(obj: FsxnDestination | undefined): Record<string, any> | undefined;
/**
 * @schema Endpoint
 */
export interface Endpoint {
    /**
     * The SVM identifier.
     *
     * @schema Endpoint#SVM
     */
    readonly svm: NameWithUuidRef;
    /**
     * The volume name within the SVM.
     *
     * @schema Endpoint#Volume
     */
    readonly volume: string;
}
/**
 * Converts an object of type 'Endpoint' to JSON representation.
 */
export declare function toJson_Endpoint(obj: Endpoint | undefined): Record<string, any> | undefined;
/**
 * @schema SnapMirrorDestinationCreation
 */
export interface SnapMirrorDestinationCreation {
    /**
     * List of aggregate names that host the volume.
     *
     * @schema SnapMirrorDestinationCreation#Aggregates
     */
    readonly aggregates: string[];
}
/**
 * Converts an object of type 'SnapMirrorDestinationCreation' to JSON representation.
 */
export declare function toJson_SnapMirrorDestinationCreation(obj: SnapMirrorDestinationCreation | undefined): Record<string, any> | undefined;
/**
 * Setting state of the relationship. Can be set during modify only.
 *
 * @schema CfnSnapMirrorPropsStateAction
 */
export declare enum CfnSnapMirrorPropsStateAction {
    /** broken_off */
    BROKEN_UNDERSCORE_OFF = "broken_off",
    /** paused */
    PAUSED = "paused",
    /** snapmirrored */
    SNAPMIRRORED = "snapmirrored",
    /** in_sync */
    IN_UNDERSCORE_SYNC = "in_sync"
}
/**
 * @schema HealthyStatus
 */
export interface HealthyStatus {
    /**
     * Indicates whether the relationship is healthy.
     *
     * @schema HealthyStatus#Healthy
     */
    readonly healthy?: boolean;
    /**
     * Reason the relationship is not healthy.
     *
     * @schema HealthyStatus#UnhealthyReason
     */
    readonly unhealthyReason?: string[];
}
/**
 * Converts an object of type 'HealthyStatus' to JSON representation.
 */
export declare function toJson_HealthyStatus(obj: HealthyStatus | undefined): Record<string, any> | undefined;
/**
 * @schema SecretSource
 */
export interface SecretSource {
    /**
     * The ARN of the secret stored in AWS Secrets Manager.
     *
     * @schema SecretSource#SecretArn
     */
    readonly secretArn: string;
    /**
     * Reference for the SecretKey. The actual password is stored in AWS Secret Manager.
     *
     * @schema SecretSource#SecretKey
     */
    readonly secretKey: string;
}
/**
 * Converts an object of type 'SecretSource' to JSON representation.
 */
export declare function toJson_SecretSource(obj: SecretSource | undefined): Record<string, any> | undefined;
/**
 * @schema NameWithUuidRef
 */
export interface NameWithUuidRef {
    /**
     * The name part of the reference, which can be used to identify resources such as SVM.
     *
     * @schema NameWithUuidRef#Name
     */
    readonly name?: string;
    /**
     * The UUID part of the reference, which can be used to identify resources such as SVM.
     *
     * @schema NameWithUuidRef#UUID
     */
    readonly uuid?: string;
}
/**
 * Converts an object of type 'NameWithUuidRef' to JSON representation.
 */
export declare function toJson_NameWithUuidRef(obj: NameWithUuidRef | undefined): Record<string, any> | undefined;
/**
 * A CloudFormation `NetApp::FSxN::SnapMirror`
 *
 * @cloudformationResource NetApp::FSxN::SnapMirror
 * @stability external
 * @link https://github.com/NetApp/NetApp-CloudFormation-FSx-ONTAP-provider
 */
export declare class CfnSnapMirror extends cdk.CfnResource {
    /**
    * The CloudFormation resource type name for this resource class.
    */
    static readonly CFN_RESOURCE_TYPE_NAME = "NetApp::FSxN::SnapMirror";
    /**
     * Resource props.
     */
    readonly props: CfnSnapMirrorProps;
    /**
     * Attribute `NetApp::FSxN::SnapMirror.ID`
     * @link https://github.com/NetApp/NetApp-CloudFormation-FSx-ONTAP-provider
     */
    readonly attrId: string;
    /**
     * Attribute `NetApp::FSxN::SnapMirror.UUID`
     * @link https://github.com/NetApp/NetApp-CloudFormation-FSx-ONTAP-provider
     */
    readonly attrUuid: string;
    /**
     * Attribute `NetApp::FSxN::SnapMirror.State`
     * @link https://github.com/NetApp/NetApp-CloudFormation-FSx-ONTAP-provider
     */
    readonly attrState: string;
    /**
     * Attribute `NetApp::FSxN::SnapMirror.SourcePath`
     * @link https://github.com/NetApp/NetApp-CloudFormation-FSx-ONTAP-provider
     */
    readonly attrSourcePath: string;
    /**
     * Attribute `NetApp::FSxN::SnapMirror.DestinationPath`
     * @link https://github.com/NetApp/NetApp-CloudFormation-FSx-ONTAP-provider
     */
    readonly attrDestinationPath: string;
    /**
     * Create a new `NetApp::FSxN::SnapMirror`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnSnapMirrorProps);
}
